@@ -316,15 +316,8 @@ async def test_change_active_from_code():
         assert tabs.active_tab.id == "tab-2"
         assert tabs.active == tabs.active_tab.id
 
-        # TODO: This one is questionable. It seems Tabs has been designed so
-        # that you can set the active tab to an empty string, and it remains
-        # so, and just removes the underline; no other changes. So active
-        # will be an empty string while active_tab will be a tab. This feels
-        # like an oversight. Need to investigate and possibly modify this
-        # behaviour unless there's a good reason for this.
         tabs.active = ""
-        assert tabs.active_tab is not None
-        assert tabs.active_tab.id == "tab-2"
+        assert tabs.active_tab is None
 
 
 async def test_navigate_tabs_with_keyboard():
@@ -396,7 +389,7 @@ async def test_navigate_tabs_with_mouse():
         assert tabs.active_tab is not None
         assert tabs.active_tab.id == "tab-2"
 
-        await pilot.click("Underline")
+        await pilot.click("Underline", offset=(2, 0))
         assert tabs.active_tab is not None
         assert tabs.active_tab.id == "tab-1"
 
@@ -491,10 +484,29 @@ async def test_mouse_navigation_messages():
     async with TabsMessageCatchApp().run_test() as pilot:
         await pilot.click("#tab-2")
         await pilot.pause()
-        await pilot.click("Underline")
+        await pilot.click("Underline", offset=(2, 0))
         await pilot.pause()
         assert pilot.app.intended_handlers == [
             "on_tabs_tab_activated",
             "on_tabs_tab_activated",
             "on_tabs_tab_activated",
         ]
+
+
+async def test_disabled_tab_is_not_activated_by_clicking_underline():
+    """Regression test for https://github.com/Textualize/textual/issues/4701"""
+
+    class DisabledTabApp(App):
+        def compose(self) -> ComposeResult:
+            yield Tabs(
+                Tab("Enabled", id="enabled"),
+                Tab("Disabled", id="disabled", disabled=True),
+            )
+
+    app = DisabledTabApp()
+    async with app.run_test() as pilot:
+        # Click the underline beneath the disabled tab
+        await pilot.click(Tabs, offset=(14, 2))
+        tabs = pilot.app.query_one(Tabs)
+        assert tabs.active_tab is not None
+        assert tabs.active_tab.id == "enabled"
